%   Inputs
%       dt:   timestep size (10 femtoseconds recommended)
%       N:    number of atoms in the simulation
%       Tdes: desired system temperature (100K recommended)
%   
%   Constants:
%       amass: atomic mass (6.634e-26 kg/atom for argon)
%       sigma: atomic diameter (.3405e-9m for argon)
%       kb: Boltzmann's constant (1.380e-23 J/K*molecule)
%       epsilon: LJ potential (kb*119.8K)
%           so epsilon's units are J/molecule
%
dt = 1.e-14;
dtq2 = dt/2;
dtsq = dt^2;
dtsq2 = dtsq/2;
amass = 6.634e-26;
amassinv = 1./amass;
sigma = 0.3405e-9;
sigmainv = 1./sigma;
sigsq = sigma^2;
kb = 1.380e-23;
epsilon = 119.8*kb;
eps24 = 24.*epsilon;
%
% Set initial positions as a function of sigma
%
%   Using the MATLAB 'ndgrid' routine and subsequent modifier 
%
N = input('Enter the number of atoms you wish to model:  ');
N3rd = round(N^(1/3));
disp('Number of atoms adjusted to the following for a proper initial grid:')
N = N3rd^3;
disp(N)
NL = 1.25*(N3rd-1)/2;
bigeyes = 1.e10*eye(N);
[rx,ry,rz] = ndgrid(-NL:1.25:NL, -NL:1.25:NL, -NL:1.25:NL);  % creates matrixed cartesian coordinates
boxLqs = 4.*NL;  %the periodic boundary can be adjusted if desired
axislim = boxLqs/2.
rx = rx(:); ry = ry(:); rz = rz(:);  % modifier needed to change from matrix to vector mode
%
% Checking initial positions
%
asize = 100.0; % in points... therefore not actual dimensions
scatter3(rx,ry,rz,asize,'r','filled')
axis([-axislim axislim -axislim axislim -axislim axislim])
axis vis3d;
disp('Atom grid initialized... see plot then press any key to continue') 
pause
rx = sigma.*rx;
ry = sigma.*ry;
rz = sigma.*rz;
boxL = sigma*boxLqs;
qboxL = 1./boxL;
%
%  Computing a random initial velocity based on desired system temperature
%
Tdes = input('Enter the desired system temperature (100K recommended):  ');
Vxmean = sqrt(kb*Tdes/amass);
Vymean = Vxmean;
Vzmean = Vxmean;
%
% Set initial velocity distributions as a function of desired temperture, 
% Tdes (K)
%
Vx = Vxmean.*randn(N,1);
Vy = ???
Vz = ???
%
% Correcting for velocity drift
%
Ninv = 1./N;
Vx = Vx - (Ninv*sum(Vx)).*ones(N,1);
Vy = ???
Vz = ???
disp('Actual initial system temperature from normal distribution comps:')
%
%  T = (amass/(3*n*KB))*Vsq
%     Note: Vsq can be computed by summing the dot 
%           products of the velocity component vectors
%
Tinit = (amass/(3*N*kb))*sum(???);
disp(Tinit)
%
%  Time step loop
%
Vsq = 0.;
Timelapse = 0.;
kdtend = input('Enter the desired number of time steps:  ');
%
for kdt = 1:kdtend
%
%   Set the position vectors as NxN matrixes for 
%      computing the ij distances
%
%   The i atoms are set as N columns of positions...
%
    rxi = repmat(rx,1,N);
    ryi = ???
    rzi = ???
%
%   ...while the j atoms are set as N rows
%
    rxj = rxi';
    ryj = ???
    rzj = ???
%
%   ... so the difference between the matrices give intermolecular distances
%
    rxij = rxi - rxj;
    ryij = ???
    rzij = ???
    %
    % correcting of distances for periodic boundaries
    %
    rxij = rxij - boxL*round(qboxL*rxij);
    ryij = ???
    rzij = ??? 
    %
    % Force Computations
    %
    rijsq = rxij.*rxij + ryij.*ryij + rzij.*rzij;
    %
    % Diagonal Correction: 
    %   Since i-i forces would compute as infinite, we add a large diagonal 
    %   matrix to rijsq to simulate very large distances and therefore zero forces
    %
    rijsq = rijsq + bigeyes;
    rsqinv = 1./rijsq;
    sqr2 = sigsq.*rsqinv;
    sqr6 = sqr2.*sqr2.*sqr2;
    sqr12 = sqr6.*sqr6;
    fqrij = eps24.*rsqinv.*(???);
    fxij = fqrij.*rxij;
    fyij = ???
    fzij = ???
    fx = sum(fxij,2);
    fy = sum(???,2);
    fz = sum(???,2);
    ax = amassinv*fx;
    ay = ???
    az = ???
    % 
    %  Modified Verlet Algorithm for computing molecular displacements
    %
    %  ax, ay, az already computed based on rij
    %
    Vx = Vx + dtq2*ax;
    Vy = ???
    Vz = ???
    rx = rx + dt*Vx + dtsq2*ax;
    ry = ???
    rz = ???
    Vx = Vx + dtq2*ax;
    Vy = ???
    Vz = ???
    %
    % Correcting of periodic boundary positions after movement is computed
    % 
    %   Periodic boundary logic:
    %       if(rx(i)> boxL/2) rx(i) = rx(i) - boxL; end
    %       if(rx(i)<-boxL/2) rx(i) = rx(i) + boxL; end
    %          and repeated for y and z dimensions
    %
    %   Instead do the following to cut the computation time down:
    %
    rx = rx - boxL*round(qboxL*rx);
    ry = ???
    rz = ???
    %
    %  Gathering average kinetic energies for system temperature checks
    %
    % if kdt >= 76
        Vsq = Vsq + sum((Vx.*Vx) + (Vy.*Vy) + (Vz.*Vz));
    % end
end  % End of the do loop for time iterations    
%
%  Updating scatter plot of atoms
%
rxplot = sigmainv*rx;
ryplot = sigmainv*ry;
rzplot = sigmainv*rz; 
scatter3(rxplot,ryplot,rzplot,asize,'b','filled')
axis([-axislim axislim -axislim axislim -axislim axislim])
axis vis3d;
disp('Time loop completed.  Elapsed time (in nanoseconds) is: ')
Timelapse = Timelapse + kdtend*dt*1e9;
disp(Timelapse)
Temp = (amass/(3*N*kb))*(Vsq/kdtend);
disp('Average system temperature over the time loop:')
disp(Temp)
disp('See updated plot then press any key to continue')
pause
disp ('When you're ready, don't forget to include the use of MDcont')
% disp('Run MDcont if you wish to continue this simulation')


